OC.L10N.register(
    "firstrunwizard",
    {
    "About" : "Тухай",
    "Desktop client" : "захиалагчийн дэлгэц",
    "Server address" : "хүлээн авагчийн хаяг",
    "Copy link" : "Холбоос хуулах",
    "Copied!" : "Хуулсан!",
    "Not supported!" : "Дэмжигдэхгүй",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу."
},
"nplurals=2; plural=(n != 1);");
